#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_INT_SPLAT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_INT_SPLAT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/int_splat.hpp>

#endif
